@@ -61,7 +61,9 @@ def check_backup(backup_dir) -> VersionInfo:
     versioninfo = VersionInfo(version)
 
     if not versioninfo.is_tested_version():
-        logger.warn(f"Found untested Signal database version: {version}.")
+        logger.warn(
+            f"This database version is untested, please report errors."
+        )
     return versioninfo
 
 
@@ -309,7 +311,7 @@ def get_group_update_data_v2(rawbody, addressbook, mid):
     members = []
     change_by = None
     editor = None
-    if change.by:
+    if (not change is None) and (not change.by is None):
         editor = get_member_by_raw_uuid(
             change.by, "update editor", addressbook, mid
         )
